Creates candidate starting values evenly spread across the parameter bounds. Low-signal data gets more starts with the slope biased small.
Arguments
- model_constraints
Output of
compute_model_constraints().
Creates candidate starting values evenly spread across the parameter bounds. Low-signal data gets more starts with the slope biased small.
Output of compute_model_constraints().